package main

import (
	"context"
	"embed"

	"github.com/wailsapp/wails/v2"
	"github.com/wailsapp/wails/v2/pkg/options"
	"github.com/wailsapp/wails/v2/pkg/options/assetserver"
)

//go:embed all:frontend/dist
var assets embed.FS

func main() {
	app := NewApp()
	homeEvent := NewHomeEvent()

	err := wails.Run(&options.App{
		Title:  "浏览器多开工具",
		Width:  800,
		Height: 500,
		AssetServer: &assetserver.Options{
			Assets: assets,
		},
		BackgroundColour: &options.RGBA{R: 27, G: 38, B: 54, A: 1},
		OnStartup: func(ctx context.Context) {
			app.startup(ctx)
			homeEvent.startup(ctx)
		},
		Bind: []interface{}{
			app,
			homeEvent,
		},
	})

	if err != nil {
		println("Error:", err.Error())
	}
}
